Package: virustotal
Title: R Client for the 'VirusTotal' API
Version: 0.6.0
Authors@R: person("Gaurav", "Sood", email = "gsood07@gmail.com",
                  role = c("aut", "cre"))
Description: Provides a comprehensive R interface to the 'VirusTotal' API v3.0
    <https://docs.virustotal.com/>, a Google service that analyzes files and
    URLs for viruses, worms, trojans and other malware. Features include
    file/URL scanning, domain categorization, passive DNS information, IP
    reputation analysis, IoC relationships, sandbox analysis, and
    comment/voting systems. Implements rate limiting, error handling, and
    response validation for robust security analysis workflows.
URL: https://github.com/themains/virustotal,
        https://themains.github.io/virustotal/
BugReports: https://github.com/themains/virustotal/issues
Depends: R (>= 4.0.0)
License: MIT + file LICENSE
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
Imports: httr (>= 1.4.0), dplyr (>= 1.0.0), base64enc (>= 0.1-3),
        jsonlite (>= 1.7.0), checkmate (>= 2.0.0), rlang (>= 1.0.0)
Suggests: knitr (>= 1.30), rmarkdown (>= 2.0), testthat (>= 3.0.0),
        lintr (>= 3.0.0), httptest (>= 4.0.0), covr, pkgdown, spelling
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Config/Needs/website: pkgdown
NeedsCompilation: no
Packaged: 2026-04-12 16:22:25 UTC; soodoku
Author: Gaurav Sood [aut, cre]
Maintainer: Gaurav Sood <gsood07@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-13 07:30:02 UTC
Built: R 4.5.2; ; 2026-04-13 09:01:33 UTC; unix
