Tests and Coverage
================
06 November, 2018 18:49:57

This output is created by
[covrpage](https://github.com/yonicd/covrpage).

## Coverage

Coverage summary is created using the
[covr](https://github.com/r-lib/covr) package.

| Object                                     | Coverage (%) |
| :----------------------------------------- | :----------: |
| virustotal                                 |      0       |
| [R/add\_comments.R](../R/add_comments.R)   |      0       |
| [R/domain\_report.R](../R/domain_report.R) |      0       |
| [R/file\_report.R](../R/file_report.R)     |      0       |
| [R/ip\_report.R](../R/ip_report.R)         |      0       |
| [R/rescan\_file.R](../R/rescan_file.R)     |      0       |
| [R/scan\_file.R](../R/scan_file.R)         |      0       |
| [R/scan\_url.R](../R/scan_url.R)           |      0       |
| [R/set\_key.R](../R/set_key.R)             |      0       |
| [R/url\_report.R](../R/url_report.R)       |      0       |
| [R/virustotal.R](../R/virustotal.R)        |      0       |

<br>

## Unit Tests

Unit Test summary is created using the
[testthat](https://github.com/r-lib/testthat)
package.

| file                                                      | n | time | error | failed | skipped | warning | icon |
| :-------------------------------------------------------- | -: | ---: | ----: | -----: | ------: | ------: | :--- |
| [test-data-structures.R](testthat/test-data-structures.R) | 1 |    0 |     0 |      0 |       1 |       0 | \+   |
| [test-pkg-style.R](testthat/test-pkg-style.R)             | 1 |    0 |     0 |      0 |       1 |       0 | \+   |

<details open>

<summary> Show Detailed Test Results
</summary>

| file                                                         | context                | test                                             | status  | n | time | icon |
| :----------------------------------------------------------- | :--------------------- | :----------------------------------------------- | :------ | -: | ---: | :--- |
| [test-data-structures.R](testthat/test-data-structures.R#L6) | Verify data structures | can decrypt secrets and data structures verified | SKIPPED | 1 |    0 | \+   |
| [test-pkg-style.R](testthat/test-pkg-style.R#L5)             | lints                  | Package Style                                    | SKIPPED | 1 |    0 | \+   |

| Failed | Warning | Skipped |
| :----- | :------ | :------ |
| \!     | \-      | \+      |

</details>

<details>

<summary> Session Info </summary>

| Field    | Value                            |
| :------- | :------------------------------- |
| Version  | R version 3.5.1 (2018-07-02)     |
| Platform | x86\_64-w64-mingw32/x64 (64-bit) |
| Running  | Windows 10 x64 (build 17134)     |
| Language | English\_United States           |
| Timezone | America/Los\_Angeles             |

| Package  | Version |
| :------- | :------ |
| testthat | 2.0.1   |
| covr     | 3.2.1   |
| covrpage | 0.0.62  |

</details>

<!--- Final Status : skipped/warning --->
