% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/security.R
\name{is_api_key_configured}
\alias{is_api_key_configured}
\title{Check if API key is properly configured}
\usage{
is_api_key_configured()
}
\value{
Logical indicating if API key is configured
}
\description{
Verifies that the API key is set and appears to be valid format.
}
\seealso{
Other security: 
\code{\link{sanitize_domain}()},
\code{\link{sanitize_file_path}()},
\code{\link{sanitize_hash}()},
\code{\link{sanitize_ip}()},
\code{\link{sanitize_url}()},
\code{\link{security-utilities}}
}
\concept{security}
\keyword{internal}
