% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/errors.R
\name{print.virustotal_error}
\alias{print.virustotal_error}
\title{Print method for VirusTotal errors}
\usage{
\method{print}{virustotal_error}(x, ...)
}
\arguments{
\item{x}{A virustotal_error object}

\item{...}{Additional arguments (unused)}
}
\description{
Print method for VirusTotal errors
}
\keyword{internal}
