% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/virustotal.R
\name{virustotal_check}
\alias{virustotal_check}
\title{Request Response Verification}
\usage{
virustotal_check(req)
}
\arguments{
\item{req}{HTTP response object from httr}
}
\value{
Invisible NULL on success, throws structured errors on failure
}
\description{
Enhanced error checking with structured error classes
}
\seealso{
Other error handling: 
\code{\link{virustotal-errors}},
\code{\link{virustotal_auth_error}()},
\code{\link{virustotal_error}()},
\code{\link{virustotal_rate_limit_error}()},
\code{\link{virustotal_validation_error}()}
}
\concept{error handling}
\keyword{internal}
