% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3_classes.R
\name{summary.virustotal_response}
\alias{summary.virustotal_response}
\title{Summary method for VirusTotal responses}
\usage{
\method{summary}{virustotal_response}(object, ...)
}
\arguments{
\item{object}{A virustotal_response object}

\item{...}{Additional arguments (unused)}
}
\description{
Summary method for VirusTotal responses
}
\keyword{internal}
