% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rate_limiting.R
\name{reset_rate_limit}
\alias{reset_rate_limit}
\title{Reset rate limiting state}
\usage{
reset_rate_limit()
}
\description{
Clears all rate limiting history. Useful for testing.
}
\seealso{
Other rate limiting: 
\code{\link{get_rate_limit_status}()},
\code{\link{rate-limiting}},
\code{\link{rate_limit}()}
}
\concept{rate limiting}
\keyword{internal}
