% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{format_file_size}
\alias{format_file_size}
\title{Convert file size to human readable format}
\usage{
format_file_size(size_bytes)
}
\arguments{
\item{size_bytes}{File size in bytes}
}
\value{
Character string with human-readable size
}
\description{
Convert file size to human readable format
}
\seealso{
Other utilities: 
\code{\link{cleanup_temp_files}()},
\code{\link{create_safe_temp_dir}()},
\code{\link{is_safe_environment}()},
\code{\link{utilities}},
\code{\link{validate_vt_response}()},
\code{\link{virustotal_info}()},
\code{\link{virustotal_version}()}
}
\concept{utilities}
\keyword{internal}
