% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/errors.R
\name{virustotal-errors}
\alias{virustotal-errors}
\title{VirusTotal API Error Classes}
\description{
Custom error classes for structured error handling in the virustotal package.
}
\seealso{
Other error handling: 
\code{\link{virustotal_auth_error}()},
\code{\link{virustotal_check}()},
\code{\link{virustotal_error}()},
\code{\link{virustotal_rate_limit_error}()},
\code{\link{virustotal_validation_error}()}
}
\concept{error handling}
\keyword{internal}
