% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{is_safe_environment}
\alias{is_safe_environment}
\title{Check if running in a safe environment}
\usage{
is_safe_environment()
}
\value{
Logical indicating if environment is considered safe
}
\description{
Verifies that the package is running in an appropriate environment
for security analysis work.
}
\seealso{
Other utilities: 
\code{\link{cleanup_temp_files}()},
\code{\link{create_safe_temp_dir}()},
\code{\link{format_file_size}()},
\code{\link{utilities}},
\code{\link{validate_vt_response}()},
\code{\link{virustotal_info}()},
\code{\link{virustotal_version}()}
}
\concept{utilities}
\keyword{internal}
