% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/security.R
\name{security-utilities}
\alias{security-utilities}
\title{Security Utilities for VirusTotal Package}
\description{
Security functions for input sanitization and validation to prevent
common security issues when working with potentially malicious inputs.
}
\seealso{
Other security: 
\code{\link{is_api_key_configured}()},
\code{\link{sanitize_domain}()},
\code{\link{sanitize_file_path}()},
\code{\link{sanitize_hash}()},
\code{\link{sanitize_ip}()},
\code{\link{sanitize_url}()}
}
\concept{security}
\keyword{internal}
