% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{validate_vt_response}
\alias{validate_vt_response}
\title{Validate VirusTotal response structure}
\usage{
validate_vt_response(response)
}
\arguments{
\item{response}{Response object from VirusTotal API}
}
\value{
Logical indicating if response structure is valid
}
\description{
Checks if a response from VirusTotal API has the expected structure.
}
\seealso{
Other utilities: 
\code{\link{cleanup_temp_files}()},
\code{\link{create_safe_temp_dir}()},
\code{\link{format_file_size}()},
\code{\link{is_safe_environment}()},
\code{\link{utilities}},
\code{\link{virustotal_info}()},
\code{\link{virustotal_version}()}
}
\concept{utilities}
\keyword{internal}
