% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/errors.R
\name{virustotal_rate_limit_error}
\alias{virustotal_rate_limit_error}
\title{Create a rate limit error}
\usage{
virustotal_rate_limit_error(
  message = "Rate limit exceeded",
  retry_after = 60,
  call = sys.call(-1)
)
}
\arguments{
\item{message}{Error message}

\item{retry_after}{Number of seconds to wait before retry}

\item{call}{The calling function (automatically detected)}
}
\value{
An error object of class \code{virustotal_rate_limit_error}
}
\description{
Create a rate limit error
}
\seealso{
Other error handling: 
\code{\link{virustotal-errors}},
\code{\link{virustotal_auth_error}()},
\code{\link{virustotal_check}()},
\code{\link{virustotal_error}()},
\code{\link{virustotal_validation_error}()}
}
\concept{error handling}
\keyword{internal}
