% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rate_limiting.R
\name{rate-limiting}
\alias{rate-limiting}
\title{Rate Limiting for VirusTotal API}
\description{
Modern rate limiting implementation that properly manages API request limits.
VirusTotal public API allows 4 requests per minute.
}
\seealso{
Other rate limiting: 
\code{\link{get_rate_limit_status}()},
\code{\link{rate_limit}()},
\code{\link{reset_rate_limit}()}
}
\concept{rate limiting}
\keyword{internal}
