% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_analysis.R
\name{get_analysis}
\alias{get_analysis}
\title{Get Analysis Results}
\usage{
get_analysis(id = NULL, ...)
}
\arguments{
\item{id}{Analysis ID (character string). Required.}

\item{\dots}{Additional arguments passed to \code{\link{virustotal_GET}}.}
}
\value{
list containing analysis results including status and detection stats
}
\description{
Retrieves the results of a file or URL analysis by its analysis ID.
}
\examples{
\dontrun{

# Before calling the function, set the API key using set_key('api_key_here')

get_analysis(id='NjY0MjRlOTFjMDIyYTkyNWM0NjU2NWQzYWNlMzFmZmI6MTI4NTk')
}
}
\references{
\url{https://docs.virustotal.com/reference/analysis}
}
\seealso{
\code{\link{set_key}} for setting the API key
}
