% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_behaviour_html.R
\name{get_behaviour_html}
\alias{get_behaviour_html}
\title{Get Behaviour HTML Report}
\usage{
get_behaviour_html(sandbox_id = NULL, output_path = NULL, ...)
}
\arguments{
\item{sandbox_id}{Sandbox report ID (character string). Required.}

\item{output_path}{Local path to save the HTML file. Optional.}

\item{\dots}{Additional arguments passed to httr::GET.}
}
\value{
Raw HTML content or saves to file if output_path specified
}
\description{
Retrieves a detailed HTML report from a sandbox analysis.
}
\examples{
\dontrun{

# Before calling the function, set the API key using set_key('api_key_here')

html <- get_behaviour_html(sandbox_id='hash_sandboxname')
get_behaviour_html(sandbox_id='hash_sandboxname',
                   output_path='/tmp/report.html')
}
}
\references{
\url{https://docs.virustotal.com/reference}
}
\seealso{
\code{\link{set_key}} for setting the API key,
\code{\link{get_behaviour_report}} for JSON report
}
