% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rate_limiting.R
\name{init_rate_limit}
\alias{init_rate_limit}
\title{Initialize rate limiting state}
\usage{
init_rate_limit()
}
\description{
Initialize rate limiting state
}
\keyword{internal}
