% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/set_key.R
\name{set_key}
\alias{set_key}
\title{Set VirusTotal API Key}
\usage{
set_key(api_key = NULL)
}
\arguments{
\item{api_key}{VirusTotal API key (character string). Required.}
}
\value{
Invisibly returns TRUE on success
}
\description{
Stores your VirusTotal API key in an environment variable for use by other
package functions. Get your API key from \url{https://www.virustotal.com/}.
}
\examples{
\dontrun{
# Set your API key
set_key('your_64_character_api_key_here')

# Verify it's set
Sys.getenv("VirustotalToken")
}
}
\references{
\url{https://docs.virustotal.com/reference}
}
\concept{authentication}
