% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rate_limiting.R
\name{rate_limit}
\alias{rate_limit}
\title{Modern rate limiting implementation}
\usage{
rate_limit(force_wait = FALSE)
}
\arguments{
\item{force_wait}{Logical. If TRUE, will wait even if under limit}
}
\value{
Invisible TRUE
}
\description{
Uses a sliding window approach to track requests and enforce limits.
This replaces the old environment variable-based approach.
}
\seealso{
Other rate limiting: 
\code{\link{get_rate_limit_status}()},
\code{\link{rate-limiting}},
\code{\link{reset_rate_limit}()}
}
\concept{rate limiting}
\keyword{internal}
